@@ -3,8 +3,8 @@
 from __future__ import annotations
 
 import asyncio
-from datetime import datetime
 import logging
+from datetime import datetime
 from typing import Any, Callable
 
 import aiohttp
@@ -22,42 +22,31 @@ from asusrouter import (
     Monitor,
 )
 from asusrouter.const import (
+    ACTION_MODE,
     AIMESH,
-    AR_DEVICE_IDENTITY,
-    AR_KEY_AURARGB,
-    AR_KEY_LED,
-    AR_KEY_LEDG_COUNT,
+    APPLY,
     AR_KEY_LEDG_RGB,
     AR_KEY_LEDG_SCHEME,
     AR_KEY_LEDG_SCHEME_OLD,
-    AR_KEY_PARENTAL_CONTROL,
-    AR_KEY_SERVICE_COMMAND,
-    AR_KEY_SERVICE_MODIFY,
-    AR_KEY_SERVICE_REPLY,
     AR_LEDG_MODE,
-    AR_MAP_PARENTAL_CONTROL,
-    AR_PATH,
-    AR_SERVICE_COMMAND,
-    AR_SERVICE_CONTROL,
-    AR_SERVICE_DROP_CONNECTION,
     BOOTTIME,
     CLIENTS,
+    CLIENTS_HISTORIC,
+    COMMAND,
     CONNECTION_TYPE,
     CONST_REQUIRE_MONITOR,
     CONVERTERS,
     CPU,
     CPU_USAGE,
-    DEFAULT_ACTION_MODE,
     DEFAULT_CACHE_TIME,
     DEFAULT_SLEEP_TIME,
+    DELIMITER_PARENTAL_CONTROL_ITEM,
     DEVICEMAP,
     ENDHOOKS,
     ENDPOINT,
     ENDPOINTS,
     ERRNO,
     ERROR_IDENTITY,
-    ERROR_SERVICE,
-    ERROR_SERVICE_UNKNOWN,
     ERROR_VALUE,
     ETHERNET_PORTS,
     FIRMWARE,
@@ -68,56 +57,71 @@ from asusrouter.const import (
     INFO,
     IP,
     ISO,
-    KEY_ACTION_MODE,
-    KEY_WAN,
+    KEY_PARENTAL_CONTROL_MAC,
+    KEY_PARENTAL_CONTROL_STATE,
+    KEY_PARENTAL_CONTROL_TYPE,
     LAN,
+    LED,
+    LED_VAL,
+    LEDG,
+    LIGHT,
     LINK_RATE,
     MAC,
     MAIN,
     MAP_CONNECTED_DEVICE,
+    MAP_IDENTITY,
     MAP_NVRAM,
     MAP_OVPN_STATUS,
+    MAP_PARENTAL_CONTROL_ITEM,
+    MAP_PARENTAL_CONTROL_TYPE,
     MEMORY_USAGE,
     MONITOR_REQUIRE_CONST,
+    NAME,
     NETDEV,
     NETWORK,
-    NVRAM,
-    ONLINE,
-    RAM,
-    RANGE_GWLAN,
-    TOTAL,
-    UPDATE_CLIENTS,
-    USED,
-    WANLINK_STATE,
-    WLAN,
-    WLAN_TYPE,
-    Merge,
-    MSG_INFO,
-    MSG_SUCCESS,
     NODE,
+    NVRAM,
     ONBOARDING,
+    ONLINE,
     PARAM_COLOR,
     PARAM_COUNT,
     PARAM_MODE,
+    PARENTAL_CONTROL,
     PORT,
     PORT_STATUS,
     PORT_TYPES,
     PORTS,
+    RAM,
+    RANGE_GWLAN,
     RANGE_OVPN_CLIENTS,
     RSSI,
+    RULES,
+    SERVICE_COMMAND,
+    SERVICE_MODIFY,
+    SERVICE_REPLY,
+    SERVICE_SET_LED,
     SPEED_TYPES,
     STATE,
     STATUS,
     SYS,
     SYSINFO,
     TEMPERATURE,
+    TIMEMAP,
     TIMESTAMP,
+    TOTAL,
     TRACK_SERVICES_LED,
+    TYPE,
     UNKNOWN,
+    UPDATE_CLIENTS,
     USB,
+    USED,
     VPN,
     VPN_CLIENT,
     WAN,
+    WANLINK_STATE,
+    WLAN,
+    WLAN_TYPE,
+    Merge,
 )
 from asusrouter.dataclass import AiMeshDevice, ConnectedDevice
 from asusrouter.util import calculators, compilers, converters, parsers
@@ -144,10 +148,6 @@ class AsusRouter:
 
         self._cache_time: int = cache_time
 
-        self._device_cpu_cores: list[int] | None = None
-        self._device_ports: dict[str, str] | None = None
-        self._device_boottime: datetime | None = None
-
         # Monitors
         self.monitor: dict[str, Monitor] = {
             endpoint: Monitor() for endpoint in ENDPOINT
@@ -169,8 +169,11 @@ class AsusRouter:
         self._ledg_color: dict[int, dict[str, int]] | None = None
         self._ledg_count: int = 0
         self._ledg_mode: int | None = None
-        self._status_led: bool = False
 
+        # State values
+        self._state_led: bool = False
+
+        # Flags
         self._flag_reboot: bool = False
 
         """Connect"""
@@ -190,9 +193,11 @@ class AsusRouter:
             DEVICEMAP: self._process_monitor_devicemap,
             ETHERNET_PORTS: self._process_monitor_ethernet_ports,
             FIRMWARE: self._process_monitor_firmware,
+            LIGHT: self._process_monitor_light,
             MAIN: self._process_monitor_main,
             NVRAM: self._process_monitor_nvram,
             ONBOARDING: self._process_monitor_onboarding,
+            PARENTAL_CONTROL: self._process_monitor_parental_control,
             PORT_STATUS: self._process_monitor_port_status,
             SYSINFO: self._process_monitor_sysinfo,
             TEMPERATURE: self._process_monitor_temperature,
@@ -218,13 +223,13 @@ class AsusRouter:
         if self._flag_reboot:
             await self.async_handle_reboot()
 
-    ### MAIN CONTROL -->
+    # MAIN CONTROL -->
 
     async def async_check_endpoint(self, endpoint: str) -> bool:
         """Check if endpoint exists"""
 
         try:
-            await self.connection.async_load(endpoint)
+            await self.async_api_load(endpoint)
             return True
         except AsusRouter404:
             return False
@@ -272,17 +277,17 @@ class AsusRouter:
     async def async_identify(self) -> None:
         """Identify the device"""
 
-        _LOGGER.debug(MSG_INFO["identifying"])
+        _LOGGER.debug("Identifying the device")
 
         # Compile
         query = []
-        for item in AR_DEVICE_IDENTITY:
+        for item in MAP_IDENTITY:
             query.append(item)
 
         # Collect data
         message = compilers.nvram(query)
         try:
-            raw = await self.async_hook(message, force=True)
+            raw = await self.async_api_hook(message)
         except Exception as ex:
             raise AsusRouterIdentityError(
                 ERROR_IDENTITY.format(self._host, str(ex))
@@ -290,7 +295,7 @@ class AsusRouter:
 
         # Parse
         identity = {}
-        for item in AR_DEVICE_IDENTITY:
+        for item in MAP_IDENTITY:
             key = item.get()
             try:
                 data = item.method(raw[item.value]) if item.method else raw[item.value]
@@ -331,31 +336,35 @@ class AsusRouter:
             self.monitor[endpoint].enabled = identity[ENDPOINTS][
                 endpoint
             ] = await self.async_check_endpoint(address)
-        identity["update_networkmapd"] = await self.async_check_endpoint(
-            endpoint=AR_PATH["networkmap"]
-        )
-
-        # Check RGBG / AURA
-        try:
-            data = await self.connection.async_load(AR_PATH["rgb"])
-            if AR_KEY_AURARGB in data:
-                identity["aura"] = True
-            elif AR_KEY_LEDG_COUNT in data:
-                identity["ledg"] = True
-                self._ledg_count = parsers.ledg_count(data)
-        except AsusRouter404 as ex:
-            """Do nothing"""
 
         # Save static values
-        self._status_led = raw[AR_KEY_LED]
+        self._state_led = raw[LED_VAL]
 
+        # Save identity
         self._identity = AsusDevice(**identity)
 
-        _LOGGER.debug(MSG_SUCCESS["identity"])
+        _LOGGER.debug("Identity collected")
 
-    ### <-- MAIN CONTROL
+    # <-- MAIN CONTROL
 
-    ### DATA PROCESSING -->
+    # API COMMUNICATIONS -->
+
+    async def async_api_command(
+        self,
+        commands: dict[str, str] | None = None,
+        endpoint: str = ENDPOINT[COMMAND],
+    ) -> dict[str, Any]:
+        """Send a command to API"""
+
+        return await self.async_api_load(endpoint=endpoint, command=str(commands))
+
+    async def async_api_hook(self, hook: str | None = None) -> dict[str, Any]:
+        """Hook data from API"""
+
+        return await self.async_api_load(
+            endpoint=ENDPOINT[HOOK],
+            command=f"{HOOK}={hook}",
+        )
 
     async def async_api_load(
         self,
@@ -366,7 +375,7 @@ class AsusRouter:
 
         # Endpoint should be selected
         if endpoint is None:
-            _LOGGER.debug(MSG_INFO["empty_request"])
+            _LOGGER.debug("No endpoint selected")
             return {}
 
         # Process endpoint
@@ -374,81 +383,22 @@ class AsusRouter:
             result = await self.connection.async_run_command(
                 command=command, endpoint=endpoint
             )
+        # HTTP 404 should be processed separately
+        except AsusRouter404 as ex:
+            raise AsusRouter404 from ex
         except Exception as ex:
             raise ex
 
-        return result
-
-    async def async_command(
-        self,
-        commands: dict[str, str] | None = None,
-        action_mode: str = DEFAULT_ACTION_MODE,
-        apply_to: str = AR_PATH["command"],
-    ) -> dict[str, Any]:
-        """Command device to run a service or set parameter"""
-
-        result = {}
-
-        request: dict = {
-            KEY_ACTION_MODE: action_mode,
-        }
-        if commands is not None:
-            for command in commands:
-                request[command] = commands[command]
-
-        try:
-            result = await self.connection.async_run_command(
-                command=str(request), endpoint=apply_to
-            )
-        except Exception as ex:
-            raise ex
-
-        return result
-
-    async def async_hook(
-        self, hook: str | None = None, force: bool = False
-    ) -> dict[str, Any]:
-        """Hook data from device"""
-
-        result = {}
-
-        if hook is None:
-            _LOGGER.debug(MSG_INFO["empty_request"])
-            return result
-
-        try:
-            result = await self.connection.async_run_command(command=f"{HOOK}={hook}")
-        except Exception as ex:
-            raise ex
-
-        # Check for errors during hook
+        # Check for errors during API call
         if self.connection.error:
-            _LOGGER.debug(MSG_INFO["error_flag"])
+            _LOGGER.debug("Error flag found. Fixing")
             await self._async_handle_error()
 
         return result
 
-    async def async_load(self, page: str | None = None) -> dict[str, Any]:
-        """Return the data from the page"""
+    # <-- API COMMUNICATIONS
 
-        result = {}
-
-        if page is None:
-            _LOGGER.debug(MSG_INFO["empty_request"])
-            return result
-
-        try:
-            result = await self.connection.async_run_command(command="", endpoint=page)
-        except AsusRouter404 as ex:
-            raise ex
-        except Exception as ex:
-            raise ex
-
-        return result
-
-    ### <-- DATA PROCESSING
-
-    ### MONITORS -->
+    # MONITORS -->
 
     async def async_monitor(self, endpoint: str) -> None:
         """Monitor an endpoint"""
@@ -494,13 +444,16 @@ class AsusRouter:
         """Check whether monitor is available"""
 
         # Monitor does not exist
-        if not monitor in self.monitor:
+        if monitor not in self.monitor:
+            _LOGGER.debug("Monitor `%s` does not exist", monitor)
             return False
 
         # Monitor is disabled
         if not self.monitor[monitor].enabled:
+            _LOGGER.debug("Monitor `%s` is disabled", monitor)
             return False
 
+        _LOGGER.debug("Monitor `%s` is enabled", monitor)
         return True
 
     async def async_monitor_cached(self, monitor: str, value: Any) -> bool:
@@ -509,11 +462,20 @@ class AsusRouter:
         now = datetime.utcnow()
         if (
             not self.monitor[monitor].ready
-            or not value in self.monitor[monitor]
+            or value not in self.monitor[monitor]
             or self._cache_time < (now - self.monitor[monitor].time).total_seconds()
         ):
+            _LOGGER.debug(
+                "Value `%s` is not in cache yet by monitor `%s` "
+                "or the caching time has already expired",
+                value,
+                monitor,
+            )
             return False
 
+        _LOGGER.debug(
+            "Value `%s` is already cached by monitor `%s`. Using cache", value, monitor
+        )
         return True
 
     async def async_monitor_ready(self, monitor: str, retry=False) -> bool:
@@ -524,13 +486,22 @@ class AsusRouter:
             if requirement:
                 value = self.constant.get(requirement)
                 if value:
+                    _LOGGER.debug(
+                        "Required constant found. Trying to compile monitor `%s`",
+                        monitor,
+                    )
                     self.monitor_compile[monitor](value)
                     return True
-                else:
-                    if not retry and requirement in CONST_REQUIRE_MONITOR:
-                        await self.async_monitor(CONST_REQUIRE_MONITOR[requirement])
-                        return await self.async_monitor_ready(monitor, retry=True)
-                    return False
+                if not retry and requirement in CONST_REQUIRE_MONITOR:
+                    _LOGGER.debug(
+                        "Monitor `%s` requires constant `%s` to be found first. "
+                        "Initializing corresponding monitor",
+                        monitor,
+                        requirement,
+                    )
+                    await self.async_monitor(CONST_REQUIRE_MONITOR[requirement])
+                    return await self.async_monitor_ready(monitor, retry=True)
+                return False
             return False
         return True
 
@@ -553,17 +524,21 @@ class AsusRouter:
 
         return True
 
-    ### COMPILE MONITORS
+    # COMPILE MONITORS
 
     def _compile_monitor_nvram(self, wlan: list[str]) -> None:
         """Compile `nvram` monitor"""
 
+        _LOGGER.debug("Compiling monitor NVRAM")
+
         arg = compilers.monitor_arg_nvram(wlan)
         if arg:
             self.monitor_arg[NVRAM] = f"hook={arg}"
         self.monitor[NVRAM].ready = True
 
-    ### PROCESS MONITORS
+        _LOGGER.debug("Monitor NVRAM was compiled")
+
+    # PROCESS MONITORS
 
     def _process_monitor_devicemap(self, raw: Any, time: datetime) -> dict[str, Any]:
         """Process data from `devicemap` endpoint"""
@@ -610,7 +585,7 @@ class AsusRouter:
                 vpn[key] = {}
                 if f"{key}_{STATE}" in vpnmap:
                     status = converters.int_from_str(vpnmap[f"{key}_{STATE}"])
-                    vpn[key][STATE] = True if status > 0 else False
+                    vpn[key][STATE] = status > 0
                     vpn[key][STATUS] = MAP_OVPN_STATUS.get(
                         status, f"{UNKNOWN} ({status})"
                     )
@@ -655,7 +630,7 @@ class AsusRouter:
         fw_current = self._identity.firmware
         fw_new = parsers.firmware_string(raw["webs_state_info"])
 
-        firmware["state"] = True if fw_current < fw_new else False
+        firmware[STATE] = fw_current < fw_new
         firmware["current"] = str(fw_current)
         firmware["available"] = str(fw_new)
 
@@ -663,6 +638,19 @@ class AsusRouter:
             FIRMWARE: firmware,
         }
 
+    def _process_monitor_light(self, raw: Any, time: datetime) -> dict[str, Any]:
+        """Process data from `light` endpoint"""
+
+        # LED
+        led = {}
+        if LED_VAL in raw:
+            led[STATE] = converters.bool_from_any(raw[LED_VAL])
+            self._state_led = led[STATE]
+
+        return {
+            LED: led,
+        }
+
     def _process_monitor_main(self, raw: Any, time: datetime) -> dict[str, Any]:
         """Process data from `main` endpoint"""
 
@@ -701,7 +689,7 @@ class AsusRouter:
 
         # Network
         network = {}
-        ## Data in Bytes for traffic and bits/s for speeds
+        # Data in Bytes for traffic and bits/s for speeds
         if NETDEV in raw:
             # Calculate RX and TX from the HEX values.
             # If there is no current value, but there was one before, get it from storage.
@@ -721,7 +709,7 @@ class AsusRouter:
         elif self.monitor[MAIN].ready and NETWORK in self.monitor[MAIN]:
             network = self.monitor[MAIN][NETWORK]
 
-        if not USB in network and "dualwan" in self._identity.services:
+        if USB not in network and "dualwan" in self._identity.services:
             network[USB] = {}
         # Save constant
         constant = []
@@ -737,7 +725,7 @@ class AsusRouter:
             wan = parsers.wan_state(raw=raw[WANLINK_STATE])
         # Keep last data
         elif self.monitor[MAIN].ready and WAN in self.monitor[MAIN]:
-            wan = self.monitor[MAIN][KEY_WAN]
+            wan = self.monitor[MAIN][WAN]
 
         return {
             CPU: cpu,
@@ -818,6 +806,44 @@ class AsusRouter:
             CLIENTS: clients,
         }
 
+    def _process_monitor_parental_control(
+        self, raw: Any, time: datetime
+    ) -> dict[str, Any]:
+        """Process data from `parental control` endpoint"""
+
+        parental_control = {}
+
+        # State
+        parental_control[STATE] = None
+        if KEY_PARENTAL_CONTROL_STATE in raw:
+            parental_control[STATE] = converters.bool_from_any(
+                raw[KEY_PARENTAL_CONTROL_STATE]
+            )
+
+        # Rules
+        rules = {}
+
+        if raw.get(KEY_PARENTAL_CONTROL_MAC) != raw.get(KEY_PARENTAL_CONTROL_TYPE):
+            as_is = {}
+            for element in MAP_PARENTAL_CONTROL_ITEM:
+                temp = raw[element.value].split(DELIMITER_PARENTAL_CONTROL_ITEM)
+                as_is[element.get()] = []
+                for temp_element in temp:
+                    as_is[element.get()].append(element.method(temp_element))
+
+            number = len(as_is[MAC])
+            for i in range(0, number):
+                rules[as_is[MAC][i]] = FilterDevice(
+                    mac=as_is[MAC][i],
+                    name=as_is[NAME][i],
+                    type=MAP_PARENTAL_CONTROL_TYPE.get(as_is[TYPE][i], UNKNOWN),
+                    timemap=as_is[TIMEMAP][i],
+                )
+
+        parental_control[RULES] = rules.copy()
+
+        return {PARENTAL_CONTROL: parental_control}
+
     def _process_monitor_port_status(self, raw: Any, time: datetime) -> dict[str, Any]:
         """Process data from `port status` endpoint"""
 
@@ -869,13 +895,14 @@ class AsusRouter:
         """Process data from `update_clients` endpoint"""
 
         # Clients
-        clients = {}
+        clients_historic = {}
         if "nmpClient" in raw:
             data = raw["nmpClient"][0]
             for mac, description in data.items():
                 if converters.is_mac_address(mac):
-                    clients[mac] = description
+                    clients_historic[mac] = description
 
+        clients = {}
         if "fromNetworkmapd" in raw:
             data = raw["fromNetworkmapd"][0]
             for mac, description in data.items():
@@ -884,6 +911,7 @@ class AsusRouter:
 
         return {
             CLIENTS: clients,
+            CLIENTS_HISTORIC: clients_historic,
         }
 
     def _process_monitor_vpn(self, raw: Any, time: datetime) -> dict[str, Any]:
@@ -896,9 +924,9 @@ class AsusRouter:
             VPN: vpn,
         }
 
-    ### <-- MONITORS
+    # <-- MONITORS
 
-    ### TECHNICAL -->
+    # TECHNICAL -->
 
     async def _async_handle_error(self) -> None:
         """Actions to be taken on connection error"""
@@ -913,12 +941,10 @@ class AsusRouter:
     def _init_constant(self, constant: str, value: Any) -> None:
         """Initialize constant"""
 
+        _LOGGER.debug("Initializing constant `%s`=`%s`", constant, value)
         self.constant[constant] = value
-        for monitor, const in MONITOR_REQUIRE_CONST.items():
-            if constant == const:
-                self.monitor[monitor].ready = True
 
-    ### <-- TECHNICAL
+    # <-- TECHNICAL
 
     async def async_handle_reboot(self) -> None:
         """Actions to be taken on reboot"""
@@ -927,7 +953,7 @@ class AsusRouter:
 
         return
 
-    ### PROCESS DATA -->
+    # PROCESS DATA -->
 
     def _process_data_none(self, raw: dict[str, Any]) -> dict[str, Any]:
         """Don't process the data"""
@@ -962,9 +988,9 @@ class AsusRouter:
 
         return raw
 
-    ### <-- PROCESS DATA
+    # <-- PROCESS DATA
 
-    ### RETURN DATA -->
+    # RETURN DATA -->
 
     async def async_get_data(
         self,
@@ -998,14 +1024,17 @@ class AsusRouter:
             return {}
 
         # Process monitors
-        for monitor in monitors:
+        for _monitor in monitors:
 
             # Value is not cached or cache is disabled
-            if not await self.async_monitor_cached(monitor, data) or use_cache is False:
-                await self.async_monitor(monitor)
+            if (
+                not await self.async_monitor_cached(_monitor, data)
+                or use_cache is False
+            ):
+                await self.async_monitor(_monitor)
 
             # Receive data
-            part = self.monitor[monitor].get(data or {})
+            part = self.monitor[_monitor].get(data or {})
 
             # Update data
             compilers.update_rec(result, part)
@@ -1031,11 +1060,6 @@ class AsusRouter:
             data=BOOTTIME, monitor=DEVICEMAP, use_cache=use_cache
         )
 
-    async def async_get_cpu(self, use_cache: bool = True) -> dict[str, float]:
-        """Return CPU data"""
-
-        return await self.async_get_data(data=CPU, monitor=MAIN, use_cache=use_cache)
-
     async def async_get_connected_devices(
         self, use_cache: bool = True
     ) -> dict[str, ConnectedDevice]:
@@ -1049,6 +1073,11 @@ class AsusRouter:
             process=self._process_data_connected_devices,
         )
 
+    async def async_get_cpu(self, use_cache: bool = True) -> dict[str, float]:
+        """Return CPU data"""
+
+        return await self.async_get_data(data=CPU, monitor=MAIN, use_cache=use_cache)
+
     async def async_get_devicemap(self, use_cache: bool = True) -> dict[str, Any]:
         """Return devicemap data"""
 
@@ -1070,6 +1099,11 @@ class AsusRouter:
 
         return await self.async_get_data(data=GWLAN, monitor=NVRAM, use_cache=use_cache)
 
+    async def async_get_led(self, use_cache: bool = True) -> dict[str, Any]:
+        """Return LED data"""
+
+        return await self.async_get_data(data=LED, monitor=LIGHT, use_cache=use_cache)
+
     async def async_get_network(
         self, use_cache: bool = True
     ) -> dict[str, (int | float)]:
@@ -1079,6 +1113,15 @@ class AsusRouter:
             data=NETWORK, monitor=MAIN, use_cache=use_cache
         )
 
+    async def async_get_parental_control(
+        self, use_cache: bool = True
+    ) -> dict[str, (int | float)]:
+        """Return parental control data"""
+
+        return await self.async_get_data(
+            data=PARENTAL_CONTROL, monitor=PARENTAL_CONTROL, use_cache=use_cache
+        )
+
     async def async_get_ports(
         self, use_cache: bool = True
     ) -> dict[str, dict[str, int]]:
@@ -1124,9 +1167,29 @@ class AsusRouter:
 
         return await self.async_get_data(data=WLAN, monitor=NVRAM, use_cache=use_cache)
 
-    ### NOT PROCESSED -->
+    # <-- RETURN DATA
 
-    ### PARENTAL CONTROL -->
+    # APPLY -->
+
+    # LED
+    async def async_set_led(self, value: bool | int | str) -> bool:
+        """Set LED state"""
+
+        value_to_set = converters.bool_from_any(value)
+
+        service = SERVICE_SET_LED
+        arguments = {
+            ACTION_MODE: APPLY,
+            LED_VAL: converters.int_from_bool(value_to_set),
+        }
+
+        result = await self.async_service_generic(service=service, arguments=arguments)
+
+        if result:
+            self._state_led = value_to_set
+        return result
+
+    # Parental control
     async def async_apply_parental_control_rules(
         self,
         rules: dict[str, FilterDevice],
@@ -1134,48 +1197,13 @@ class AsusRouter:
         """Apply parental control rules"""
 
         request = compilers.parental_control(rules)
-        request["action_mode"] = "apply"
+        request[ACTION_MODE] = APPLY
 
-        return await self.async_service_run(
+        return await self.async_service_generic(
             service="restart_firewall",
             arguments=request,
         )
 
-    async def async_get_parental_control(self) -> dict[str, Any]:
-        """Return parental control status"""
-
-        # NVRAM values to check
-        nvram = []
-        nvram.append(AR_KEY_PARENTAL_CONTROL.value)
-        for value in AR_MAP_PARENTAL_CONTROL:
-            nvram.append(value)
-
-        data = await self.async_hook(compilers.nvram(nvram))
-        data = parsers.parental_control(data)
-
-        return data
-
-    async def async_get_parental_control_rules(
-        self,
-        macs: str | list[str] | None = None,
-    ) -> dict[str, FilterDevice]:
-        """Return parental control rules"""
-
-        pc: dict = await self.async_get_parental_control()
-        rules = pc.get("list", {})
-
-        # Return the full list if no device specified
-        if macs is None:
-            return rules
-
-        # Return only devices of interest
-        result = {}
-        macs = converters.as_list(macs)
-        for mac in macs:
-            if mac in rules:
-                result[mac] = rules[mac]
-        return result
-
     async def async_remove_parental_control_rules(
         self,
         macs: str | list[str] | None = None,
@@ -1188,22 +1216,22 @@ class AsusRouter:
         rules = [] if rules is None else converters.as_list(rules)
 
         # Get current rules
-        cr: dict = await self.async_get_parental_control_rules()
+        current_rules: dict = (await self.async_get_parental_control())[RULES]
 
         # Remove old rules for these MACs
         for mac in macs:
-            if mac in cr:
-                cr.pop(mac)
+            if mac in current_rules:
+                current_rules.pop(mac)
         for rule in rules:
-            if rule.mac in cr:
-                cr.pop(rule.mac)
+            if rule.mac in current_rules:
+                current_rules.pop(rule.mac)
 
         # Apply new rules
         if apply:
-            await self.async_apply_parental_control_rules(cr)
+            await self.async_apply_parental_control_rules(current_rules)
 
         # Return the new rules
-        return cr
+        return current_rules
 
     async def async_set_parental_control_rules(
         self,
@@ -1214,107 +1242,83 @@ class AsusRouter:
         rules = converters.as_list(rules)
 
         # Remove old rules for these MACs and get the rest of the list
-        cr = await self.async_remove_parental_control_rules(rules, apply=False)
+        current_rules = await self.async_remove_parental_control_rules(
+            rules, apply=False
+        )
 
         # Add new rules
         for rule in rules:
-            cr[rule.mac] = rule
+            current_rules[rule.mac] = rule
 
         # Apply new rules
-        return await self.async_apply_parental_control_rules(cr)
+        return await self.async_apply_parental_control_rules(current_rules)
 
-    ### <-- PARENTAL CONTROL
+    # <-- APPLY
 
-    ### <-- RETURN DATA
+    # SERVICE -->
 
-    ### SERVICE RUN -->
-
-    async def async_service_run(
+    async def async_service_generic(
         self,
         service: str,
         arguments: dict[str, Any] | None = None,
         expect_modify: bool = True,
         drop_connection: bool = False,
     ) -> bool:
-        """Generic service to run"""
+        """Run generic service"""
 
+        # Generate commands
+        # Should include service name to run
+        # and default mode to apply changes
         commands = {
-            AR_KEY_SERVICE_COMMAND: service,
+            SERVICE_COMMAND: service,
         }
 
+        # Add arguments if any
         if arguments:
             commands.update(arguments)
 
+        # Try running the service command
         try:
-            result = await self.async_command(commands=commands)
+            result = await self.async_api_command(commands=commands)
         except AsusRouterServerDisconnectedError as ex:
-            # For services, that will block any further connections
             if drop_connection:
-                _LOGGER.debug(MSG_INFO["drop_connection_service"].format(service))
+                _LOGGER.debug(
+                    "Service `%s` requires dropping connection to the device", service
+                )
                 await self.async_drop_connection()
                 return True
-            else:
-                raise ex
+            raise ex
 
+        # Check for the run success
         if (
-            not AR_KEY_SERVICE_REPLY in result
-            or result[AR_KEY_SERVICE_REPLY] != service
-            or not AR_KEY_SERVICE_MODIFY in result
+            SERVICE_REPLY not in result
+            or result[SERVICE_REPLY] != service
+            or SERVICE_MODIFY not in result
         ):
-            raise AsusRouterServiceError(ERROR_SERVICE.format(service, result))
-
-        _LOGGER.debug(MSG_INFO["service"].format(service, arguments, result))
+            raise AsusRouterServiceError(
+                f"Something went wrong running service `{service}`."
+                f"Raw result is: {result}"
+            )
+        _LOGGER.debug(
+            "Service `%s` was run successfully with arguments`%s`. Result: %s",
+            service,
+            arguments,
+            result,
+        )
 
+        # Check whether service(s) run requires additional actions
         services = service.split(";")
         if any(service in TRACK_SERVICES_LED for service in services):
             await self.async_keep_state_led()
 
+        # Return based on the expectations
         if expect_modify:
-            return converters.bool_from_any(result[AR_KEY_SERVICE_MODIFY])
+            return converters.bool_from_any(result[SERVICE_MODIFY])
         return True
 
-    ### SERVICES -->
+    # <-- SERVICE
 
-    async def async_service_control(self, target: str, mode: str) -> bool:
-        """Start / stop / (force) restart service"""
-
-        if not target in AR_SERVICE_CONTROL or not mode in AR_SERVICE_CONTROL[target]:
-            raise AsusRouterServiceError(ERROR_SERVICE_UNKNOWN.format(target, mode))
-
-        service = AR_SERVICE_COMMAND[mode].format(target)
-
-        drop_connection = False
-        if target in AR_SERVICE_DROP_CONNECTION:
-            drop_connection = True
-
-        return await self.async_service_run(
-            service=service, drop_connection=drop_connection
-        )
-
-    async def async_service_led_get(self) -> bool | None:
-        """Return status of the LEDs"""
-
-        key = AR_KEY_LED
-        raw = await self.async_hook(compilers.nvram(key))
-        if not converters.none_or_str(raw[key]):
-            return None
-        value = converters.bool_from_any(raw[key])
-        self._status_led = value
-        return value
-
-    async def async_service_led_set(self, value: bool | int | str) -> bool:
-        """Set status of the LEDs"""
-
-        value_to_set = converters.bool_from_any(value)
-
-        service = "start_ctrl_led"
-        arguments = {
-            AR_KEY_LED: converters.int_from_bool(value_to_set),
-        }
-        result = await self.async_service_run(service=service, arguments=arguments)
-        if result:
-            self._status_led = value_to_set
-        return result
+    # ALPHA / NOT READY -->
 
     async def async_service_ledg_get(self) -> dict[str, Any] | None:
         """Return status of RGB LEDs in LEDG scheme"""
@@ -1325,7 +1329,7 @@ class AsusRouter:
         nvram.append(AR_KEY_LEDG_SCHEME)
         nvram.append(AR_KEY_LEDG_SCHEME_OLD)
 
-        data = await self.async_hook(compilers.nvram(nvram))
+        data = await self.async_api_hook(compilers.nvram(nvram))
 
         ledg = {}
         if AR_KEY_LEDG_SCHEME in data and data[AR_KEY_LEDG_SCHEME] != str():
@@ -1354,7 +1358,7 @@ class AsusRouter:
         if self._ledg_count == 0:
             return False
 
-        if not mode in AR_LEDG_MODE:
+        if mode not in AR_LEDG_MODE:
             raise (AsusRouterValueError(ERROR_VALUE.format(mode)))
 
         # Check for the known state
@@ -1363,7 +1367,7 @@ class AsusRouter:
 
         colors = calculators.rgb(color)
         for num in range(1, self._ledg_count + 1):
-            if not num in colors:
+            if num not in colors:
                 if self._ledg_color and num in self._ledg_color:
                     colors[num] = self._ledg_color[num]
                 else:
@@ -1371,8 +1375,8 @@ class AsusRouter:
 
         color_to_set = compilers.rgb(colors)
 
-        result = await self.async_load(
-            f"{AR_PATH['ledg']}?{AR_KEY_LEDG_SCHEME}={mode}&ledg_rgb={color_to_set}"
+        result = await self.async_api_load(
+            f"{ENDPOINT[LEDG]}?{AR_KEY_LEDG_SCHEME}" f"={mode}&ledg_rgb={color_to_set}"
         )
 
         if "statusCode" in result and int(result["statusCode"]) == 200:
@@ -1380,15 +1384,15 @@ class AsusRouter:
 
         return False
 
-    ### <-- SERVICES
+    # <-- ALPHA / NOT READY
 
     async def async_keep_state_led(self) -> bool:
         """Keep state of LEDs"""
 
         # Only for Merlin firmware, so sysinfo should be present
-        if self._identity.endpoints.get(SYSINFO) and self.led is False:
-            await self.async_service_led_set(True)
-            await self.async_service_led_set(False)
+        if self._identity.endpoints.get(SYSINFO) and self.state_led is False:
+            await self.async_set_led(True)
+            await self.async_set_led(False)
 
     @property
     def connected(self) -> bool:
@@ -1396,9 +1400,9 @@ class AsusRouter:
         return self.connection.connected
 
     @property
-    def led(self) -> bool:
+    def state_led(self) -> bool:
         """LED status"""
-        return self._status_led
+        return self._state_led
 
     @property
     def ledg_count(self) -> int:
