@@ -51,7 +51,6 @@ class AsusDevice:
     ledg: bool = False
     aura: bool = False
     vpn_status: bool = False
-    update_networkmapd: bool = False
     endpoints: dict[str, bool] | None = None
 
 
@@ -217,5 +216,5 @@ class FilterDevice:
 
     mac: str | None = None
     name: str | None = None
-    state: int | None = None
+    type: int | None = None
     timemap: str = DEFAULT_PARENTAL_CONTROL_TIMEMAP
