@@ -8,32 +8,12 @@ import re
 from datetime import datetime, timedelta
 from typing import Any
 
-from dateutil.parser import parse as dtparse
 import xmltodict
+from dateutil.parser import parse as dtparse
 
 from asusrouter.const import (
-    AR_DEFAULT_CORES_RANGE,
     AR_DEFAULT_LEDG,
-    AR_DEFAULT_OVPN_CLIENTS,
-    AR_DEFAULT_OVPN_SERVERS,
-    AR_KEY_CPU_ITEM,
-    AR_KEY_CPU_LIST,
-    AR_KEY_DEVICEMAP,
     AR_KEY_HEADER,
-    AR_KEY_OVPN,
-    AR_KEY_OVPN_STATUS,
-    AR_KEY_OVPN_STATUS_SERVER,
-    AR_KEY_PARENTAL_CONTROL,
-    AR_KEY_PARENTAL_CONTROL_MAC,
-    AR_KEY_PARENTAL_CONTROL_NAME,
-    AR_KEY_PARENTAL_CONTROL_STATE,
-    AR_KEY_PARENTAL_CONTROL_TIMEMAP,
-    AR_KEY_RAM_ITEM,
-    AR_KEY_RAM_LIST,
-    AR_KEY_VPN_CLIENT,
-    AR_KEY_VPN_SERVER,
-    AR_KEY_WAN_STATE,
-    AR_MAP_PARENTAL_CONTROL_STATE,
     AR_MAP_RGB,
     AR_MAP_SYSINFO,
     AR_MAP_TEMPERATURE,
@@ -41,56 +21,49 @@ from asusrouter.const import (
     CONST_ZERO,
     CPU,
     DATA_ADD_SPEED,
+    DEVICEMAP,
     DEVICEMAP_BY_INDEX,
     DEVICEMAP_CLEAR,
     DEVICEMAP_GENERAL,
     ENDPOINT,
-    ERROR_PARSING,
     ERROR_VALUE,
     ERROR_VALUE_TYPE,
     FIRMWARE,
+    IP,
     MAP_CPU,
     MAP_NETWORK,
+    MAP_OVPN_CLIENT,
+    MAP_OVPN_SERVER,
+    MAP_RAM,
+    MAP_WAN,
+    MEM,
     ONBOARDING,
     PARAM_IP,
     PARAM_RIP,
     PARAM_STATE,
-    PARAM_STATUS,
     RANGE_CPU_CORES,
+    RANGE_OVPN_CLIENTS,
+    RANGE_OVPN_SERVERS,
     REGEX_VARIABLES,
+    RIP,
+    STATE,
+    STATUS,
     SYSINFO,
     TOTAL,
     TRAFFIC_TYPE,
     UPDATE_CLIENTS,
     VALUES_TO_IGNORE,
     VPN,
+    VPN_CLIENT,
+    VPN_SERVER,
 )
-from asusrouter.dataclass import AiMeshDevice, FilterDevice, Firmware
-from asusrouter.error import AsusRouterNotImplementedError, AsusRouterValueError
+from asusrouter.dataclass import AiMeshDevice, Firmware
+from asusrouter.error import AsusRouterValueError
 from asusrouter.util import calculators, converters
 
 _LOGGER = logging.getLogger(__name__)
 
 
-def cpu_cores(raw: dict[str, Any] | None = None) -> list[int]:
-    """CPU cores parser"""
-
-    cores = list()
-
-    if raw is None:
-        return cores
-
-    for i in AR_DEFAULT_CORES_RANGE:
-        if any(
-            AR_KEY_CPU_ITEM.format(i, data_type) in raw for data_type in AR_KEY_CPU_LIST
-        ):
-            cores.append(i)
-        else:
-            break
-
-    return cores
-
-
 def cpu_usage(raw: dict[str, Any]) -> dict[str, Any]:
     """CPU usage parser"""
 
@@ -129,14 +102,14 @@ def ram_usage(raw: dict[str, Any]) -> dict[str, Any]:
 
     ram = {}
 
-    for item in AR_KEY_RAM_LIST:
-        if AR_KEY_RAM_ITEM.format(item) in raw:
+    for item in MAP_RAM:
+        if f"{MEM}_{item.value}" in raw:
             try:
-                ram[item] = int(raw[AR_KEY_RAM_ITEM.format(item)])
+                ram[item.get()] = int(raw[f"{MEM}_{item.value}"])
             except ValueError as ex:
                 raise (
                     AsusRouterValueError(
-                        ERROR_VALUE.format(raw[AR_KEY_RAM_ITEM.format(item)], str(ex))
+                        ERROR_VALUE.format(raw[f"{MEM}_{item.value}"], str(ex))
                     )
                 ) from ex
 
@@ -210,14 +183,18 @@ def wan_state(raw: dict[str, Any]) -> dict[str, Any]:
 
     values = {}
 
-    for key in AR_KEY_WAN_STATE:
+    for key in MAP_WAN:
         if key.value in raw and raw[key.value] != str():
             try:
                 values[key.get()] = (
                     key.method(raw[key.value]) if key.method else raw[key.value]
                 )
             except AsusRouterValueError as ex:
-                _LOGGER.warning(ERROR_PARSING.format(key.value, str(ex)))
+                _LOGGER.warning(
+                    "Failed parsing value '%s'. Please report this issue. Exception summary: %s",
+                    key.value,
+                    str(ex),
+                )
 
     return values
 
@@ -236,23 +213,6 @@ def uptime(data: str) -> datetime:
     return boot
 
 
-def port_speed(value: str | None = None) -> int | None:
-    """Port speed -> Mb/s parcer"""
-
-    if value is None:
-        return None
-    elif value == "X":
-        return 0
-    elif value == "M":
-        return 100
-    elif value == "G":
-        return 1000
-    elif value == "Q":
-        return 2500
-    else:
-        raise AsusRouterNotImplementedError(value)
-
-
 def devicemap(devicemap: dict[str, Any]) -> dict[str, Any]:
     """Devicemap parser"""
 
@@ -378,7 +338,11 @@ def sysinfo(raw: str) -> dict[str, Any]:
                         else data[set][key.value]
                     )
                 except AsusRouterValueError as ex:
-                    _LOGGER.warning(ERROR_PARSING.format(key.value, str(ex)))
+                    _LOGGER.warning(
+                        "Failed parsing value '%s'. Please report this issue. Exception summary: %s",
+                        key.value,
+                        str(ex),
+                    )
 
     return result
 
@@ -446,45 +410,6 @@ def aimesh_node(raw: dict[str, Any]) -> AiMeshDevice:
     )
 
 
-def parental_control(raw: dict[str, Any]) -> dict[str, Any]:
-    """Parental control parser"""
-
-    result = {}
-
-    result[AR_KEY_PARENTAL_CONTROL.get()] = AR_KEY_PARENTAL_CONTROL.method(
-        raw[AR_KEY_PARENTAL_CONTROL.value]
-    )
-
-    # If no rules are set
-    if raw.get(AR_KEY_PARENTAL_CONTROL_MAC) == raw.get(AR_KEY_PARENTAL_CONTROL_STATE):
-        result["list"] = {}
-        return result
-
-    list = {}
-
-    for el in raw:
-        raw[el] = raw[el].split("&#62")
-
-    size = len(raw["MULTIFILTER_MAC"])
-
-    for i in range(0, size):
-        device = FilterDevice(
-            mac=raw[AR_KEY_PARENTAL_CONTROL_MAC][i],
-            name=raw[AR_KEY_PARENTAL_CONTROL_NAME][i],
-            state=AR_MAP_PARENTAL_CONTROL_STATE.get(
-                raw[AR_KEY_PARENTAL_CONTROL_STATE][i], None
-            ),
-            timemap=raw[AR_KEY_PARENTAL_CONTROL_TIMEMAP][i]
-            if i < len(raw[AR_KEY_PARENTAL_CONTROL_TIMEMAP])
-            else "",
-        )
-        list[raw[AR_KEY_PARENTAL_CONTROL_MAC][i]] = device
-
-    result["list"] = list.copy()
-
-    return result
-
-
 def endpoint_update_clients(raw: str) -> dict[str, Any]:
     """Parse data from the `update_clients` endpoint"""
 
@@ -501,23 +426,25 @@ def endpoint_update_clients(raw: str) -> dict[str, Any]:
 def pseudo_json(text: str, page: str) -> dict[str, Any]:
     """JSON parser"""
 
-    if ENDPOINT[VPN] in page:
-        return vpn_status(text)
     if ENDPOINT[FIRMWARE] in page:
         return firmware(text)
+    if ENDPOINT[STATE] in page:
+        return {}
     if ENDPOINT[UPDATE_CLIENTS] in page:
         return endpoint_update_clients(text)
+    if ENDPOINT[VPN] in page:
+        return vpn_status(text)
 
     data = re.sub(r"\s+", "", text)
 
     if "curr_coreTmp" in data:
         return temperatures(data)
     # Merlin
-    elif ENDPOINT[SYSINFO] in page:
+    if ENDPOINT[SYSINFO] in page:
         return sysinfo(data)
-    elif ENDPOINT[ONBOARDING] in page:
+    if ENDPOINT[ONBOARDING] in page:
         return onboarding(data)
-    elif "get_clientlist" in data:
+    if "get_clientlist" in data:
         data = data.replace('"get_clientlist":', '"get_clientlist":{')
         data += "}"
     elif "get_wan_lan_status=" in data:
@@ -528,7 +455,9 @@ def pseudo_json(text: str, page: str) -> dict[str, Any]:
         data = data.replace(";memInfo=", '},"memory":{')
         data = data.replace(";", "}}")
     else:
-        _LOGGER.error("Unknown data. Template for this data is unknown")
+        _LOGGER.error(
+            "Unknown data. Template for this data is unknown. Endpoint=%s}", page
+        )
         return {}
 
     return json.loads(data.encode().decode("utf-8-sig"))
@@ -538,8 +467,8 @@ def xml(text: str) -> dict[str, Any]:
     """XML parser"""
 
     data = xmltodict.parse(text)
-    if AR_KEY_DEVICEMAP in data:
-        return devicemap(data[AR_KEY_DEVICEMAP])
+    if DEVICEMAP in data:
+        return devicemap(data[DEVICEMAP])
 
     return {}
 
@@ -555,7 +484,7 @@ def ovpn_client_status(raw: str) -> dict[str, Any]:
 
     values = {}
 
-    for key in AR_KEY_OVPN_STATUS:
+    for key in MAP_OVPN_CLIENT:
         if key.value in raw:
             value = re.search(f"{key.value},(.*?)(?=>)", raw)
             if value:
@@ -575,14 +504,14 @@ def ovpn_server_status(raw: str) -> dict[str, Any]:
 
     values = {}
 
-    for key in AR_KEY_OVPN_STATUS_SERVER:
+    for key in MAP_OVPN_SERVER:
         if key.value in raw:
             flag = False
             # Find headers
             header = re.search(f"{AR_KEY_HEADER},{key.value},(.*?)(?=>)", raw)
             if header:
                 keys_raw = header[1].split(",")
-                keys = list()
+                keys = []
                 for el in keys_raw:
                     keys.append(converters.to_snake_case(el))
                 flag = True
@@ -590,7 +519,7 @@ def ovpn_server_status(raw: str) -> dict[str, Any]:
             # Hide header
             raw = raw.replace(f"{AR_KEY_HEADER},{key.value},", "USED-")
 
-            values[key.get()] = list()
+            values[key.get()] = []
             # Find values
             while value := re.search(f"{key.value},(.*?)(?=>)", raw):
                 if not value:
@@ -654,11 +583,11 @@ def firmware_string(raw: str) -> Firmware:
         raise AsusRouterValueError(ERROR_VALUE_TYPE.format(raw, type(raw)))
 
     string = re.match(
-        "^(3.?0.?0.?4)?[_.]?([0-9]{3})[_.]?([0-9]+)[_.-]?([a-zA-Z0-9-_]+)?$", raw
+        "^([39].?0.?0.?[46])?[_.]?([0-9]{3})[_.]?([0-9]+)[_.-]?([a-zA-Z0-9-_]+)?$", raw
     )
     if not string:
         _LOGGER.warning(
-            "Firmware version cannot be parser. Please report this. The original FW string is: %s",
+            "Firmware version cannot be parsed. Please report this. The original FW string is: %s",
             raw,
         )
         return Firmware()
@@ -669,7 +598,9 @@ def firmware_string(raw: str) -> Firmware:
 
     minor = int(string[2])
     build = int(string[3])
-    if string[4] and string[4].isdigit():
+    if not string[4]:
+        build_more = 0
+    elif string[4].isdigit():
         build_more = int(string[4])
     else:
         build_more = string[4]
@@ -698,12 +629,12 @@ def vpn_status(raw: str) -> dict[str, Any]:
     values = variables(raw)
 
     # Clients
-    for num in range(1, AR_DEFAULT_OVPN_CLIENTS + 1):
-        key = AR_KEY_OVPN.format(AR_KEY_VPN_CLIENT, num, PARAM_STATUS)
+    for num in RANGE_OVPN_CLIENTS:
+        key = f"{VPN_CLIENT}{num}_{STATUS}"
         if not key in values:
             break
 
-        vpn_id = AR_KEY_VPN_CLIENT + str(num)
+        vpn_id = VPN_CLIENT + str(num)
 
         if values[key] not in VALUES_TO_IGNORE:
             vpns[vpn_id] = ovpn_client_status(values[key])
@@ -712,21 +643,21 @@ def vpn_status(raw: str) -> dict[str, Any]:
             vpns[vpn_id] = {}
             vpns[vpn_id][PARAM_STATE] = False
 
-        key = AR_KEY_OVPN.format(AR_KEY_VPN_CLIENT, num, PARAM_IP)
+        key = f"{VPN_CLIENT}{num}_{IP}"
         if key in values and values[key] not in VALUES_TO_IGNORE:
             vpns[vpn_id][PARAM_IP] = values[key]
 
-        key = AR_KEY_OVPN.format(AR_KEY_VPN_CLIENT, num, PARAM_RIP)
+        key = f"{VPN_CLIENT}{num}_{RIP}"
         if key in values and values[key] not in VALUES_TO_IGNORE:
             vpns[vpn_id][PARAM_RIP] = values[key]
 
     # Servers
-    for num in range(1, AR_DEFAULT_OVPN_SERVERS + 1):
-        key = AR_KEY_OVPN.format(AR_KEY_VPN_SERVER, num, PARAM_STATUS)
+    for num in RANGE_OVPN_SERVERS:
+        key = f"{VPN_SERVER}{num}_{STATUS}"
         if not key in values:
             break
 
-        vpn_id = AR_KEY_VPN_SERVER + str(num)
+        vpn_id = VPN_SERVER + str(num)
 
         if values[key] not in VALUES_TO_IGNORE:
             vpns[vpn_id] = ovpn_server_status(values[key])
@@ -735,11 +666,11 @@ def vpn_status(raw: str) -> dict[str, Any]:
             vpns[vpn_id] = {}
             vpns[vpn_id][PARAM_STATE] = False
 
-        key = AR_KEY_OVPN.format(AR_KEY_VPN_SERVER, num, PARAM_IP)
+        key = f"{VPN_SERVER}{num}_{IP}"
         if key in values and values[key] not in VALUES_TO_IGNORE:
             vpns[vpn_id][PARAM_IP] = values[key]
 
-        key = AR_KEY_OVPN.format(AR_KEY_VPN_SERVER, num, PARAM_RIP)
+        key = f"{VPN_SERVER}{num}_{RIP}"
         if key in values and values[key] not in VALUES_TO_IGNORE:
             vpns[vpn_id][PARAM_RIP] = values[key]
 
